searchData={"items":[{"type":"module","doc":"","title":"CountryLookup","ref":"CountryLookup.html"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"CountryLookup.child_spec/1","ref":"CountryLookup.html#child_spec/1"},{"type":"function","doc":"","title":"CountryLookup.init/1","ref":"CountryLookup.html#init/1"},{"type":"function","doc":"Lookup by area code (e.g., \"7840\", \"93\", \"35818\").\nReturns a map: %{name: ..., flag_svg: ...} or nil if not found.","title":"CountryLookup.lookup_by_code/1","ref":"CountryLookup.html#lookup_by_code/1"},{"type":"function","doc":"Search countries by (partial) name, case-insensitive.\nReturns a list of maps: [%{name: ..., flag_image: ...}, ...]","title":"CountryLookup.search_by_name/1","ref":"CountryLookup.html#search_by_name/1"},{"type":"function","doc":"","title":"CountryLookup.start_link/1","ref":"CountryLookup.html#start_link/1"},{"type":"module","doc":"","title":"CountryLookup.Loader","ref":"CountryLookup.Loader.html"},{"type":"function","doc":"","title":"CountryLookup.Loader.load_data/0","ref":"CountryLookup.Loader.html#load_data/0"},{"type":"extras","doc":"# CountryLookup\n\nA lightweight Elixir library for identifying countries by their telephone dialing codes. Given a phone number or area code, or country name, country_lookup returns the matching country name and its flag as an inline image/base64.","title":"CountryLookup","ref":"readme.html"},{"type":"extras","doc":"```elixir\niex> CountryLookup.lookup_by_code(\"55\")\n%{\n  name: \"Brazil\",\n  flag_image: \"iVBORw0KGgoAAAANSUhEUgAAA...\"\n}\n\n\niex> CountryLookup.search_by_name(\"Domini\")\n[\n  %{\n    name: \"Dominica\",\n    flag_image: \"iVBORw0KGgoAAAAN...\",\n    dial_codes: [\"1767\"]\n  },\n  %{\n    name: \"Dominican Republic\",\n    flag_image: \"iVBORw0KGgoAAAANSUhEU...\",\n    dial_codes: [\"1809\", \"1829\", \"1849\"]\n  }\n]\n```","title":"Usage - CountryLookup","ref":"readme.html#usage"},{"type":"extras","doc":"🔍 Fast lookup using prefix matching (longest match wins)\n\n📞 Supports country calling codes, including national variants (e.g. 1809, 55), also search by country name.\n\n🏳️ Flag images embedded as Base64-encoded PNGs.\n\n🔌 Designed for easy integration with Phoenix LiveView or CLI apps\n\n📁 (Optional) Keep update with latest data from Wikipedia (Python):\n```shell\nconda create -n country_lookup_env python=3.10\nconda activate country_lookup_env\nconda install requests beautifulsoup4 pillow cairosvg\ncd python_skrap;\n# scrape data from Wikipedia\npython skrap.py \n```","title":"✨ Features - CountryLookup","ref":"readme.html#features"},{"type":"extras","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `country_lookup` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:country_lookup, \"~> 0.0.2\"}\n  ]\nend\n```\n\nAnd configure your `application.ex`:\n\n```elixir\n@impl true\ndef start(_type, _args) do\n  children = [\n    ...\n    CountryLookup\n  ]\n```\n\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","title":"Installation - CountryLookup","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}